EXPORTS
	??1CGSM610FR_Decoder@@QAE@XZ @ 1 NONAME ; public: __thiscall CGSM610FR_Decoder::~CGSM610FR_Decoder(void)
	??1CGSM610FR_Encoder@@QAE@XZ @ 2 NONAME ; public: __thiscall CGSM610FR_Encoder::~CGSM610FR_Encoder(void)
	?ConstructL@CGSM610FR_Decoder@@QAEXXZ @ 3 NONAME ; public: void __thiscall CGSM610FR_Decoder::ConstructL(void)
	?ConstructL@CGSM610FR_Encoder@@QAEXXZ @ 4 NONAME ; public: void __thiscall CGSM610FR_Encoder::ConstructL(void)
	?ExecuteL@CGSM610FR_Decoder@@QAEXPAE0@Z @ 5 NONAME ; public: void __thiscall CGSM610FR_Decoder::ExecuteL(unsigned char *,unsigned char *)
	?ExecuteL@CGSM610FR_Encoder@@QAEXPAE0@Z @ 6 NONAME ; public: void __thiscall CGSM610FR_Encoder::ExecuteL(unsigned char *,unsigned char *)
	?StartL@CGSM610FR_Decoder@@QAEXXZ @ 7 NONAME ; public: void __thiscall CGSM610FR_Decoder::StartL(void)
	?StartL@CGSM610FR_Encoder@@QAEXXZ @ 8 NONAME ; public: void __thiscall CGSM610FR_Encoder::StartL(void)
	?StopL@CGSM610FR_Decoder@@QAEXXZ @ 9 NONAME ; public: void __thiscall CGSM610FR_Decoder::StopL(void)
	?StopL@CGSM610FR_Encoder@@QAEXXZ @ 10 NONAME ; public: void __thiscall CGSM610FR_Encoder::StopL(void)

